==> tine20-exampleapplication_2017.08.11.tar.bz2: ExampleApplication/js/ExampleApplication-lang-he-debug.js <==
/********************** tine translations of ExampleApplication**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/ExampleApplication'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0 - ExampleApplication\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: Hebräisch\nX-Poedit-Country: \nX-Poedit-SourceCharset: utf-8\nPlural-Forms: \n"

, "ExampleRecord"
: ""

, "Name"
: ""

, "Status"
: ""

, "Reason"
: ""

, "Total Example Records"
: ""

, "New Example"
: ""

, "Status Available"
: ""

, "Possible status. Please note that additional status might impact other ExampleApplication systems on export or syncronisation."
: ""

, "Completed"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Reasons Available"
: ""

, "Possible status reasons."
: ""

, "Change"
: ""

, "Documentation"
: ""

, "Requirement Changed"
: ""

, "Not Possible"
: ""

, "Implementation"
: ""

, "Review"
: ""

, "Integration"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Sales Application."
: ""

, "Invoices Module"
: ""

, "Example String"
: ""

, "Just an example string for test purpose"
: ""

, "ExampleApplication"
: ""

, "example record, example records"
: [
  ""
 ,""

]
, "example records"
: ""

, "example record list"
: ""

, "example record lists"
: ""

, "Number"
: ""

, "Default Example Record Container"
: ""

, "The default container for new records"
: ""

, "example record"
: ""

}));

==> tine20-exampleapplication_2020.11.21.tar.bz2: ExampleApplication/js/ExampleApplication-lang-he-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ExampleApplication **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ExampleApplication'] = ({
""
: "Project-Id-Version: Tine 2.0 - ExampleApplication\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: Hebräisch\nX-Poedit-Country: \nX-Poedit-SourceCharset: utf-8\nPlural-Forms: \n"

, "Default Example Record Container"
: ""

, "The default container for new records"
: ""

, "ExampleRecord"
: ""

, "Name"
: ""

, "Status"
: ""

, "Reason"
: ""

, "Description"
: ""

, "Total Example Records"
: ""

, "New Example"
: ""

, "ExampleApplication"
: ""

, "Status Available"
: ""

, "Possible status. Please note that additional status might impact other ExampleApplication systems on export or syncronisation."
: ""

, "Completed"
: ""

, "Cancelled"
: ""

, "In process"
: ""

, "Reasons Available"
: ""

, "Possible status reasons."
: ""

, "Change"
: ""

, "Documentation"
: ""

, "Requirement Changed"
: ""

, "Not Possible"
: ""

, "Implementation"
: ""

, "Review"
: ""

, "Integration"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Example Application."
: ""

, "Invoices Module"
: ""

, "Example String"
: ""

, "Just an example string for test purpose"
: ""

, "example record, example records"
: [
  ""
 ,""

]
, "example records"
: ""

, "example record list"
: ""

, "example record lists"
: ""

, "Number"
: ""

, "datetime"
: ""

, "example record"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
